@@ -266,10 +266,11 @@ function Debugger(sel) {
     // This function is called after each control button has returned control
     // to us (step, run, etc).  The stack tabs will already be updated, but
     // enything else that needs updated goes in here.
-    function done_after_stack_update() {
+    function done_after_stack_update(next_statement) {
         $control_buttons.attr('disabled', false);
         $('#stack-tabs a:first').trigger('click');
         this.watchedExpressionManager.updateExpressions();
+        this.setCurrentStatementForCodeTable(next_statement);
     }
 
     function notifyProgramHasCompletelyExited() {
@@ -280,6 +281,56 @@ function Debugger(sel) {
         alert('Debugged program has exited');
     }
 
+    var $original_line_elt;
+    var original_line_of_code = '';
+    this.setCurrentStatementForCodeTable = function(next_statement) {
+        var $topLevelCodePane = $('div.tab-pane[data-frameno=0]'),
+            $line = $topLevelCodePane.find('.code-line.active span.code'),
+            stackFrame = this.stackManager.frame(0),
+            filename = stackFrame.filename,
+            lineno = stackFrame.line,
+            this_line_code = $line.text();
+
+        if ($original_line_elt) {
+            $original_line_elt.html(original_line_of_code);
+            $original_line_elt = undefined;
+        }
+
+        if (next_statement) {
+            // Basic chars that need to be escaped (but not parens)
+            var next_statement_re = next_statement.replace(/([.*+?^=!:${}|\[\]\/\\])/g, "\\$1");
+
+            // The deparsed next_statement can have whitespace differences from the original
+            next_statement_re = next_statement_re.replace(/\s+/g, '\\s*');
+
+            // parens can also be optional, maybe with whitespace before/after
+            next_statement_re = next_statement_re.replace(/\(/g, '\\s*\\(?\\s*');
+            next_statement_re = next_statement_re.replace(/\)/g, '\\s*\\)?\\s*');
+
+            // qq(...) is the same as "..."
+            next_statement_re = next_statement_re.replace(/(?:"|qq\\s\*\\\()(.*)(?:"|\\\))/, function(quoted, str) {
+                                                            return '(?:"|qq\\s*\\(?:\(|\{|\[|\/))' + str + '(?:"|qq\\(?:\)|\}|\]|\/))';
+                                                        });
+
+            next_statement_re = RegExp(next_statement_re);
+            // Wrap a <span> around the next_statement
+            var matched = false;
+            var marked_up_this_line_code = this_line_code.replace(next_statement_re, function (code) {
+                                                matched = true;
+                                                return '<span class="next-statement">' + code + '</span>' });
+            if (matched) {
+                // save the original look of the current line so we can restore it next time we're
+                // back in this function
+                $original_line_elt = $line;
+                original_line_of_code = $line.html();
+                // Write the marked up line back into the window
+                $line.html(marked_up_this_line_code);
+            } else {
+                console.warn("didn't find next_statement on line " + lineno + ": " + next_statement);
+            }
+        }
+    };
+
     this.controlButtonClicked = function(e) {
         e.preventDefault();
 
@@ -312,7 +363,7 @@ function Debugger(sel) {
 
         this.stackManager.update()
             .progress(this.stackFrameChanged.bind(this))
-            .done( done_after_stack_update.bind(this) );
+            .done( done_after_stack_update.bind(this, response.next_statement) );
 
         events.forEach(function(event) {
             event.render($elt)
@@ -689,8 +740,9 @@ function Debugger(sel) {
     this.stackManager = new StackManager(this.restInterface);
     this.stackManager.initialize()
         .progress(this.stackFrameChanged.bind(this))
-        .done(function() {
+        .done(function(status) {
                 done_after_stack_update.call(dbg);
+                dbg.setCurrentStatementForCodeTable(status.next_statement);
                 dbg.breakpointManager.sync();
         });
 
